//===========================
//  oCL[rbNVF[_
//===========================

float	fSharpness;
float4	vTextureSize;		// (width, height, 1/width, 1/height)
float4	vScreenResolution;	// (width, height, 1/width, 1/height)
float4	vViewPort;		// (x, y, width, height)

texture SrcTexture;

sampler	PointSampler = 
sampler_state
{
	Texture = <SrcTexture>;
	MinFilter =	POINT;
	MagFilter =	POINT;
};

struct VS_OUTPUT
{
	float4 Pos			: POSITION;
	float4 Diffuse		: COLOR0;
	float2 Tex0			: TEXCOORD0;
};

float4 PS (VS_OUTPUT In) : COLOR
{
	float	fa = -fSharpness * 1.5f - 0.5f;
	float4	f0 = float4(   fa, fa+2,  -fa-2,-fa);
	float4	f1 = float4(-fa*2,-fa-3, fa*2+3, fa);
	float4	f2 = float4(   fa,    0,    -fa,  0);
	float4	f3 = float4(    0,    1,      0,  0);

	float2	dx = float2(vTextureSize.z, 0.0f);
	float2	dy = float2(0.0f, vTextureSize.w);

	float2	ft = frac(In.Tex0 * vTextureSize);
	float2	ft2 = ft * ft;
	float2	ft3 = ft2 * ft;

	float4	fx = ft3.x * f0 + ft2.x * f1 + ft.x * f2 + f3;
	float4	fy = ft3.y * f0 + ft2.y * f1 + ft.y * f2 + f3;

	float2	t0 = In.Tex0 - dx;
	float2	t1 = In.Tex0;
	float2	t2 = In.Tex0 + dx;
	float2	t3 = t2 + dx;

	float4	col00 = tex2D( PointSampler, t0 - dy );
	float4	col01 = tex2D( PointSampler, t1 - dy );
	float4	col02 = tex2D( PointSampler, t2 - dy );
	float4	col03 = tex2D( PointSampler, t3 - dy );

	float4	col10 = tex2D( PointSampler, t0 );
	float4	col11 = tex2D( PointSampler, t1 );
	float4	col12 = tex2D( PointSampler, t2 );
	float4	col13 = tex2D( PointSampler, t3 );

	float4	col20 = tex2D( PointSampler, t0 + dy );
	float4	col21 = tex2D( PointSampler, t1 + dy );
	float4	col22 = tex2D( PointSampler, t2 + dy );
	float4	col23 = tex2D( PointSampler, t3 + dy );

	float4	col30 = tex2D( PointSampler, t0 + dy * 2 );
	float4	col31 = tex2D( PointSampler, t1 + dy * 2 );
	float4	col32 = tex2D( PointSampler, t2 + dy * 2 );
	float4	col33 = tex2D( PointSampler, t3 + dy * 2 );

	float4	col0 = fx.x * col00 + fx.y * col01 + fx.z * col02 + fx.w * col03;
	float4	col1 = fx.x * col10 + fx.y * col11 + fx.z * col12 + fx.w * col13;
	float4	col2 = fx.x * col20 + fx.y * col21 + fx.z * col22 + fx.w * col23;
	float4	col3 = fx.x * col30 + fx.y * col31 + fx.z * col32 + fx.w * col33;

	return fy.x * col0 + fy.y * col1 + fy.z * col2 + fy.w * col3;
}

technique TShader
{
    pass P0
    {
        PixelShader  = compile ps_2_0 PS();
    }
}
